NUM_ELEMS_PREVIEW_THRESHOLD = 10
BYTE_SIZE_PREVIEW_THRESHOLD = 100

# Batch size for SMD generation - adjust this to control how many objects
# are returned at once for the agent to process
SMD_GENERATION_BATCH_SIZE = 10
